limen-runtime
Limen Runtime provides concrete runtime and scheduler implementations
for executing Limen graphs. Runtimes implement the LimenRuntime trait
defined in limen-core; schedulers implement DequeuePolicy (sequential)
or WorkerScheduler (concurrent).
Status: skeleton. Module structure and scheduling algorithms are designed and partially implemented (see commented code). Full activation is tracked by the
RS1runtime lifecycle andQ1test overhaul planned items. Thelimen-examplesintegration tests drive the currently active test runtimes (TestNoStdRuntime,TestScopedRuntime) defined inlimen-core::runtime::bench.
Modules
runtime— P2 single-thread and concurrent runtime implementations.scheduler— EDF and throughputDequeuePolicyimplementations.
Feature Flags
| Flag | Effect |
|---|---|
| (default) | no_std, no heap; single-thread runtime |
alloc | enables alloc-backed runtime variants |
std | implies alloc; enables ScopedGraphApi-based concurrent runtime |